import React, { useState, useRef, useEffect, useMemo, useCallback } from "react";
import { useNavigate } from 'react-router-dom';
import {
    List,
    DatagridConfigurable,
    SearchInput,
    TopToolbar,
    SelectColumnsButton,
    EditButton,
    FilterButton,
    CreateButton,
    ExportButton,
    BulkDeleteButton,
    WrapperField,
    useRecordContext,
    useTranslate,
    useNotify,
    useListContext,
    FunctionField,
    TextField,
    NumberField,
    DateField,
    BooleanField,
    ReferenceField,
    TextInput,
    DateTimeInput,
    DateInput,
    SelectInput,
    NumberInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    DeleteButton,
} from 'react-admin';
import { Box, Typography, Card, Stack } from '@mui/material';
import { styled } from '@mui/material/styles';
import WaitPakinItemLogCreate from "./WaitPakinItemLogCreate";
import WaitPakinItemLogPanel from "./WaitPakinItemLogPanel";
import EmptyData from "../components/EmptyData";
import MyCreateButton from "../components/MyCreateButton";
import MyExportButton from '../components/MyExportButton';
import PageDrawer from "../components/PageDrawer";
import MyField from "../components/MyField";
import { PAGE_DRAWER_WIDTH, OPERATE_MODE, DEFAULT_PAGE_SIZE } from '@/config/setting';
import * as Common from '@/utils/common';

const StyledDatagrid = styled(DatagridConfigurable)(({ theme }) => ({
    '& .css-1vooibu-MuiSvgIcon-root': {
        height: '.9em'
    },
    '& .RaDatagrid-row': {
        cursor: 'auto'
    },
    '& .column-name': {
    },
    '& .opt': {
        width: 200
    },
}));

const filters = [
    <SearchInput source="condition" alwaysOn />,
    <DateInput label='common.time.after' source="timeStart" alwaysOn />,
    <DateInput label='common.time.before' source="timeEnd" alwaysOn />,

    <ReferenceInput source="pakinId" label="table.field.waitPakinItemLog.pakinId" reference="waitPakin">
        <AutocompleteInput label="table.field.waitPakinItemLog.pakinId" optionText="id" filterToQuery={(val) => ({ id: val })} />
    </ReferenceInput>,
    <NumberInput source="pakinItemId" label="table.field.waitPakinItemLog.pakinItemId" />,
    <NumberInput source="asnId" label="table.field.waitPakinItemLog.asnId" />,
    <TextInput source="asnCode" label="table.field.waitPakinItemLog.asnCode" />,
    <NumberInput source="asnItemId" label="table.field.waitPakinItemLog.asnItemId" />,
    <TextInput source="trackCode" label="table.field.waitPakinItemLog.trackCode" />,
    <TextInput source="maktx" label="table.field.waitPakinItemLog.maktx" />,
    <ReferenceInput source="matnrId" label="table.field.waitPakinItemLog.matnrId" reference="matnr">
        <AutocompleteInput label="table.field.waitPakinItemLog.matnrId" optionText="unit" filterToQuery={(val) => ({ unit: val })} />
    </ReferenceInput>,
    <TextInput source="matnrCode" label="table.field.waitPakinItemLog.matnrCode" />,
    <NumberInput source="anfme" label="table.field.waitPakinItemLog.anfme" />,
    <NumberInput source="workQty" label="table.field.waitPakinItemLog.workQty" />,
    <TextInput source="unit" label="table.field.waitPakinItemLog.unit" />,
    <TextInput source="fieldsIndex" label="table.field.waitPakinItemLog.fieldsIndex" />,
    <NumberInput source="qty" label="table.field.waitPakinItemLog.qty" />,
    <TextInput source="batch" label="table.field.waitPakinItemLog.batch" />,

    <TextInput label="common.field.memo" source="memo" />,
    <SelectInput
        label="common.field.status"
        source="status"
        choices={[
            { id: '1', name: 'common.enums.statusTrue' },
            { id: '0', name: 'common.enums.statusFalse' },
        ]}
        resettable
    />,
]

const WaitPakinItemLogList = () => {
    const translate = useTranslate();

    const [createDialog, setCreateDialog] = useState(false);
    const [drawerVal, setDrawerVal] = useState(false);

    return (
        <Box display="flex">
            <List
                sx={{
                    flexGrow: 1,
                    transition: (theme) =>
                        theme.transitions.create(['all'], {
                            duration: theme.transitions.duration.enteringScreen,
                        }),
                    marginRight: !!drawerVal ? `${PAGE_DRAWER_WIDTH}px` : 0,
                }}
                title={"menu.waitPakinItemLog"}
                empty={<EmptyData onClick={() => { setCreateDialog(true) }} />}
                filters={filters}
                sort={{ field: "create_time", order: "desc" }}
                actions={(
                    <TopToolbar>
                        <FilterButton />
                        <MyCreateButton onClick={() => { setCreateDialog(true) }} />
                        <SelectColumnsButton preferenceKey='waitPakinItemLog' />
                        <MyExportButton />
                    </TopToolbar>
                )}
                perPage={DEFAULT_PAGE_SIZE}
            >
                <StyledDatagrid
                    preferenceKey='waitPakinItemLog'
                    bulkActionButtons={() => <BulkDeleteButton mutationMode={OPERATE_MODE} />}
                    rowClick={(id, resource, record) => false}
                    expand={() => <WaitPakinItemLogPanel />}
                    expandSingle={true}
                    omit={['id', 'createTime', 'createBy', 'memo']}
                >
                    <NumberField source="id" />
                    <ReferenceField source="pakinId" label="table.field.waitPakinItemLog.pakinId" reference="waitPakin" link={false} sortable={false}>
                        <TextField source="id" />
                    </ReferenceField>
                    <NumberField source="pakinItemId" label="table.field.waitPakinItemLog.pakinItemId" />
                    <NumberField source="asnId" label="table.field.waitPakinItemLog.asnId" />
                    <TextField source="asnCode" label="table.field.waitPakinItemLog.asnCode" />
                    <NumberField source="asnItemId" label="table.field.waitPakinItemLog.asnItemId" />
                    <TextField source="trackCode" label="table.field.waitPakinItemLog.trackCode" />
                    <TextField source="maktx" label="table.field.waitPakinItemLog.maktx" />
                    <ReferenceField source="matnrId" label="table.field.waitPakinItemLog.matnrId" reference="matnr" link={false} sortable={false}>
                        <TextField source="unit" />
                    </ReferenceField>
                    <TextField source="matnrCode" label="table.field.waitPakinItemLog.matnrCode" />
                    <NumberField source="anfme" label="table.field.waitPakinItemLog.anfme" />
                    <NumberField source="workQty" label="table.field.waitPakinItemLog.workQty" />
                    <TextField source="unit" label="table.field.waitPakinItemLog.unit" />
                    <TextField source="fieldsIndex" label="table.field.waitPakinItemLog.fieldsIndex" />
                    <NumberField source="qty" label="table.field.waitPakinItemLog.qty" />
                    <TextField source="batch" label="table.field.waitPakinItemLog.batch" />

                    <ReferenceField source="updateBy" label="common.field.updateBy" reference="user" link={false} sortable={false}>
                        <TextField source="nickname" />
                    </ReferenceField>
                    <DateField source="updateTime" label="common.field.updateTime" showTime />
                    <ReferenceField source="createBy" label="common.field.createBy" reference="user" link={false} sortable={false}>
                        <TextField source="nickname" />
                    </ReferenceField>
                    <DateField source="createTime" label="common.field.createTime" showTime />
                    <BooleanField source="statusBool" label="common.field.status" sortable={false} />
                    <TextField source="memo" label="common.field.memo" sortable={false} />
                    <WrapperField cellClassName="opt" label="common.field.opt">
                        <EditButton sx={{ padding: '1px', fontSize: '.75rem' }} />
                        <DeleteButton sx={{ padding: '1px', fontSize: '.75rem' }} mutationMode={OPERATE_MODE} />
                    </WrapperField>
                </StyledDatagrid>
            </List>
            <WaitPakinItemLogCreate
                open={createDialog}
                setOpen={setCreateDialog}
            />
            <PageDrawer
                title='WaitPakinItemLog Detail'
                drawerVal={drawerVal}
                setDrawerVal={setDrawerVal}
            >
            </PageDrawer>
        </Box>
    )
}

export default WaitPakinItemLogList;
